import webbrowser
from pkg_resources import resource_listdir
from pkg_resources import resource_filename


def browse():
    """
    list all of the vignettes available for this package
    """
    outs = _get_vignette_titles()

    if len(outs) > 0:
        stri = "\nAvailable documents: \n"
        print(stri)
        for i in outs:
            print(i)
        print("\nTo open use e.g load_vignette('" + str(outs[0]) + "')\n")
    else:
        print("No documents available")


def load_vignette(name):
    """
    grab a particular vignette from the package
    """
    outs = _get_vignette_titles()
    if any(n == name for n in outs):
        path = resource_filename("jrpystan", 'vignettes/')
        webbrowser.open_new(path + name)
    else:
        print("Does not match any vignettes")
        browse()


def _get_vignette_titles():
    x = resource_listdir("jrpystan", 'vignettes/')
    # grab only those which are pdfs or html
    pdfs = [s for s in x if ".pdf" in s]
    htmls = [s for s in x if ".html" in s]
    outs = pdfs + htmls
    return outs



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['jrpystan']

package_data = \
{'': ['*'], 'jrpystan': ['data/*']}

install_requires = \
['arviz>=0.12.0,<0.13.0',
 'matplotlib>=3.5.1,<4.0.0',
 'numpy>=1.22.3,<2.0.0',
 'pandas>=1.4.2,<2.0.0',
 'pystan>=3.4.0,<4.0.0']

setup_kwargs = {
    'name': 'jrpystan',
    'version': '1.1.0',
    'description': 'Jumping Rivers: Introduction to Bayesian inference using PyStan',
    'long_description': None,
    'author': 'Jumping Rivers',
    'author_email': 'info@jumpingrivers.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
